<?php

class PingTest extends Tests\SyncTestCase
{

    /**
     * Test Ping command
     */
    public function testFolderSyncBasic()
    {
        $request = <<<EOF
            <?xml version="1.0" encoding="utf-8"?>
            <!DOCTYPE AirSync PUBLIC "-//AIRSYNC//DTD AirSync//EN" "http://www.microsoft.com/">
            <Ping xmlns="uri:Ping">
                <HeartbeatInterval>900</HeartbeatInterval>
                <Folders>
                    <Folder>
                        <Id>38b950ebd62cd9a66929c89615d0fc04</Id>
                        <Class>Email</Class>
                    </Folder>
                </Folders>
            </Ping>
            EOF;

        $response = $this->request($request, 'Ping');

        $this->assertEquals(200, $response->getStatusCode());

        $dom = $this->fromWbxml($response->getBody());
        $xpath = $this->xpath($dom);
        $this->printDom($dom);

        //Initially we know no folders
        $this->assertSame('7', $xpath->query("//ns:Ping/ns:Status")->item(0)->nodeValue);


        //We discover folders with a foldersync
        $request = <<<EOF
            <?xml version="1.0" encoding="utf-8"?>
            <!DOCTYPE AirSync PUBLIC "-//AIRSYNC//DTD AirSync//EN" "http://www.microsoft.com/">
            <FolderSync xmlns="uri:FolderHierarchy">
                <SyncKey>0</SyncKey>
            </FolderSync>
            EOF;

        $response = $this->request($request, 'FolderSync');
        $this->assertEquals(200, $response->getStatusCode());

        //Now we get to the actual ping
        $request = <<<EOF
            <?xml version="1.0" encoding="utf-8"?>
            <!DOCTYPE AirSync PUBLIC "-//AIRSYNC//DTD AirSync//EN" "http://www.microsoft.com/">
            <Ping xmlns="uri:Ping">
                <HeartbeatInterval>0</HeartbeatInterval>
                <Folders>
                    <Folder>
                        <Id>38b950ebd62cd9a66929c89615d0fc04</Id>
                        <Class>Email</Class>
                    </Folder>
                </Folders>
            </Ping>
            EOF;

        $response = $this->request($request, 'Ping');
        $this->assertEquals(200, $response->getStatusCode());
        $dom = $this->fromWbxml($response->getBody());
        $xpath = $this->xpath($dom);
        // $this->printDom($dom);
        //Initially we know no folders
        $this->assertSame('2', $xpath->query("//ns:Ping/ns:Status")->item(0)->nodeValue);
    }

    /**
     * Test Ping command
     */
    public function testUnknownFolder()
    {
        $request = <<<EOF
            <?xml version="1.0" encoding="utf-8"?>
            <!DOCTYPE AirSync PUBLIC "-//AIRSYNC//DTD AirSync//EN" "http://www.microsoft.com/">
            <Ping xmlns="uri:Ping">
                <HeartbeatInterval>900</HeartbeatInterval>
                <Folders>
                    <Folder>
                        <Id>foobar</Id>
                        <Class>Email</Class>
                    </Folder>
                </Folders>
            </Ping>
            EOF;

        $response = $this->request($request, 'Ping');

        $this->assertEquals(200, $response->getStatusCode());

        $dom = $this->fromWbxml($response->getBody());
        $xpath = $this->xpath($dom);
        // $this->printDom($dom);

        $this->assertSame('7', $xpath->query("//ns:Ping/ns:Status")->item(0)->nodeValue);
    }
}
